@@ -17,7 +17,7 @@ class NotReorderableTest implements Test
         return 1;
     }
 
-    public function run(TestResult $result = null): TestResult
+    public function run(?TestResult $result = null): TestResult
     {
         return new TestResult;
     }
