@@ -41,6 +41,7 @@ use PHPUnit\TestFixture\SampleClass;
 use PHPUnit\TestFixture\Struct;
 use PHPUnit\Util\Xml\Exception as XmlException;
 use PHPUnit\Util\Xml\Loader as XmlLoader;
+use SebastianBergmann\RecursionContext\InvalidArgumentException;
 use SplObjectStorage;
 use stdClass;
 
@@ -262,8 +263,8 @@ final class AssertTest extends TestCase
     /**
      * @dataProvider equalProvider
      *
-     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
      * @throws ExpectationFailedException
+     * @throws InvalidArgumentException
      */
     public function testAssertEqualsSucceeds($a, $b): void
     {
@@ -273,8 +274,8 @@ final class AssertTest extends TestCase
     /**
      * @dataProvider notEqualProvider
      *
-     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
      * @throws ExpectationFailedException
+     * @throws InvalidArgumentException
      */
     public function testAssertEqualsFails($a, $b): void
     {
@@ -286,8 +287,8 @@ final class AssertTest extends TestCase
     /**
      * @dataProvider notEqualProvider
      *
-     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
      * @throws ExpectationFailedException
+     * @throws InvalidArgumentException
      */
     public function testAssertNotEqualsSucceeds($a, $b): void
     {
@@ -299,8 +300,8 @@ final class AssertTest extends TestCase
      *
      * @dataProvider equalProvider
      *
-     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
      * @throws ExpectationFailedException
+     * @throws InvalidArgumentException
      */
     public function testAssertNotEqualsFails($a, $b): void
     {
@@ -314,8 +315,8 @@ final class AssertTest extends TestCase
      *
      * @dataProvider sameProvider
      *
-     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
      * @throws ExpectationFailedException
+     * @throws InvalidArgumentException
      */
     public function testAssertSameSucceeds($a, $b): void
     {
@@ -327,8 +328,8 @@ final class AssertTest extends TestCase
      *
      * @dataProvider notSameProvider
      *
-     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
      * @throws ExpectationFailedException
+     * @throws InvalidArgumentException
      */
     public function testAssertSameFails($a, $b): void
     {
@@ -342,8 +343,8 @@ final class AssertTest extends TestCase
      *
      * @dataProvider notSameProvider
      *
-     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
      * @throws ExpectationFailedException
+     * @throws InvalidArgumentException
      */
     public function testAssertNotSameSucceeds($a, $b): void
     {
@@ -355,8 +356,8 @@ final class AssertTest extends TestCase
      *
      * @dataProvider sameProvider
      *
-     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
      * @throws ExpectationFailedException
+     * @throws InvalidArgumentException
      */
     public function testAssertNotSameFails($a, $b): void
     {
@@ -1407,8 +1408,8 @@ XML;
     /**
      * @dataProvider validInvalidJsonDataprovider
      *
-     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
      * @throws ExpectationFailedException
+     * @throws InvalidArgumentException
      */
     public function testAssertJsonStringEqualsJsonStringErrorRaised($expected, $actual): void
     {
@@ -1431,8 +1432,8 @@ XML;
      *
      * @dataProvider validInvalidJsonDataprovider
      *
-     * @throws \SebastianBergmann\RecursionContext\InvalidArgumentException
      * @throws ExpectationFailedException
+     * @throws InvalidArgumentException
      */
     public function testAssertJsonStringNotEqualsJsonStringErrorRaised($expected, $actual): void
     {
